@@ -905,8 +905,14 @@ sub create_symlinks {
             rename ("$bdir/$_", "$bdir/$_.v1")  # rename razor1 
         }
         print "Creating symlink $1 <== $bdir/$_\n";
-        symlink $1, "$bdir/$_";
-    }
+        symlink($1, "$bdir/$_") if $^O ne 'VMS';
+        
+        # Do VMS specific stuff.
+        if ($^O eq 'VMS' ) {
+            my ($disk, $dir, $file) = File::Spec->splitpath($1);
+            File::Copy::copy($1,File::Spec->catpath($disk,$dir,"$_"));
+        }
+     }
 }
 
 
@@ -979,8 +985,11 @@ sub loadservercache {
         }
     }
     my @fns;
+    my $sep = '\.';
+    $sep = '_' if $^O eq 'VMS';
     if (opendir D,$self->{razorhome}) {
-        @fns = map "$self->{razorhome}/$_", grep /^server\.[\S]+\.conf$/, readdir D;
+        @fns = map {s/_/./g; "$self->{razorhome}/$_";} grep /^server$sep[\S]+\.conf$/, readdir D;
+        @fns = map { /^(\S+)$/, $1 } @fns; # untaint
         closedir D;
     }
     foreach (@fns) {
